@@ -207,6 +207,8 @@ class Settings(NextDnsData):
     cname_flattening: bool
     anonymized_ecs: bool
     logs: bool
+    logs_location: str
+    logs_retention: int
     web3: bool
 
     allow_affiliate: bool
